Compares parameter estimates between pooled and unpooled two-sex models to assess the effect of partial pooling.
Examples
if (FALSE) { # \dontrun{
comp <- compare_pooling(growth_pooled, growth_unpooled)
print(comp)
} # }
Compares parameter estimates between pooled and unpooled two-sex models to assess the effect of partial pooling.
if (FALSE) { # \dontrun{
comp <- compare_pooling(growth_pooled, growth_unpooled)
print(comp)
} # }